:orphan:



.. _sphx_glr__gallery:

.. This directory contains scripts to use as tutorials to understand the package
   Use plot_*.py for script that intend to display some feature and will be
   rendered in the package gallery

Gallery
=======

Example plots of available features


.. raw:: html

    <div class="sphx-glr-clear"></div>



.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
